@@ -1,10 +1,10 @@
 # coding=utf-8
-from datatype import DataType
-from values import Values
-from times import Times
-from db_utils import DBHelper
-from random_data.random_abstract import RandomData
-from faker import Faker
+from . datatype import DataType
+from . values import Values
+from . times import Times
+from . db_utils import DBHelper
+from . random_data.random_abstract import RandomData
+from . faker import Faker
 
 # 数据类型
 DataType = DataType
