@@ -1,4 +1,4 @@
-from sql_faker import Faker, DataType, DBHelper, Values
+from . sql_faker import Faker, DataType, DBHelper, Values
 import random
 
 DBHelper.db_setting('python-sql-faker37')
